==> image-loader-1.7.1-sources.jar: com/budiyev/android/imageloader/PlaceholderDrawable.java <==
/*
 * MIT License
 *
 * Copyright (c) 2017 Yuriy Budiyev [yuriy.budiyev@yandex.ru]
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.budiyev.android.imageloader;

import java.lang.ref.WeakReference;

import android.graphics.drawable.Drawable;
import android.graphics.drawable.LayerDrawable;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

/**
 * {@link Drawable} that holds reference to {@link DisplayImageAction}
 */
final class PlaceholderDrawable extends LayerDrawable {
    private final WeakReference<DisplayImageAction<?>> mActionReference;

    public PlaceholderDrawable(@NonNull Drawable placeholder,
            @NonNull DisplayImageAction<?> action) {
        super(new Drawable[] {placeholder});
        mActionReference = new WeakReference<DisplayImageAction<?>>(action);
    }

    /**
     * {@link DisplayImageAction} attached to this drawable
     */
    @Nullable
    public DisplayImageAction<?> getAction() {
        return mActionReference.get();
    }
}

==> image-loader-2.0.9-sources.jar: com/budiyev/android/imageloader/PlaceholderDrawable.java <==
/*
 * MIT License
 *
 * Copyright (c) 2017 Yuriy Budiyev [yuriy.budiyev@yandex.ru]
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.budiyev.android.imageloader;

import java.lang.ref.WeakReference;

import android.graphics.drawable.Drawable;
import android.graphics.drawable.LayerDrawable;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

/**
 * {@link Drawable} that holds reference to {@link DisplayImageAction}
 */
final class PlaceholderDrawable extends LayerDrawable {
    private final WeakReference<DisplayImageAction<?>> mActionReference;

    public PlaceholderDrawable(@NonNull Drawable placeholder, @NonNull DisplayImageAction<?> action) {
        super(new Drawable[] {placeholder});
        mActionReference = new WeakReference<DisplayImageAction<?>>(action);
    }

    /**
     * {@link DisplayImageAction} attached to this drawable
     */
    @Nullable
    public DisplayImageAction<?> getAction() {
        return mActionReference.get();
    }
}
